==> fuckasd_0.3.tar.gz: fuckasd/scripts/fuckasd_config.sh <==
#!/bin/sh

source /koolshare/scripts/base.sh
eval $(dbus export fuckasd_)
alias echo_date='echo 【$(TZ=UTC-8 date -R +%Y年%m月%d日\ %X)】:'
LOG_FILE=/tmp/upload/fuckasd_log.txt
FUCKASD_LOG_FILE=/tmp/upload/fuckasd.log
LOCK_FILE=/var/lock/fuckasd.lock
BASH=${0##*/}
ARGS=$@
file="asd"
target_dir="/koolshare/bin/" 
file_path=$(which "$file")

set_lock(){
	exec 999>${LOCK_FILE}
	flock -n 999 || {
		# bring back to original log
		http_response "$ACTION"
		exit 1
	}
}

unset_lock(){
	flock -u 999
	rm -rf ${LOCK_FILE}
}

number_test(){
	case $1 in
		''|*[!0-9]*)
			echo 1
			;;
		*)
			echo 0
			;;
	esac
}

fuckAsus(){
  # 检查文件是否找到
  if [ -n "$file_path" ]; then
    echo_date "找到 $file，路径为 $file_path"
    
    # 构建目标挂载点
    mount_point="$target_dir/$file"
    #生成挂载文件
    echo "#!/bin/sh

while true
do
sleep 86400
done" > $mount_point

    #赋权
    chmod +x $mount_point

    #杀掉所有命令
    killall $file > /dev/null 2>&1
    killall $file > /dev/null 2>&1
    killall $file > /dev/null 2>&1
    
    # 执行挂载
    mount --bind "$mount_point" "$file_path"
    echo_date "Fuck $file 成功"
  else
    echo_date "$file 未找到，您不需要fuckasd"
    echo_date "关闭插件"
    dbus set fuckasd_enable=0
  fi
}

stopfuck(){
  killall asd && unmount "$mount_point" "$file_path"
}

case $1 in
start)
	if [ "${fuckasd_enable}" == "1" ]; then
		logger "[软件中心-开机自启]: fuckasd开始自动启动！"
		fuckAsus
	else
		logger "[软件中心-开机自启]: fuckasd未开启，不自动启动！"
	fi
	;;
boot_up)
	if [ "${fuckasd_enable}" == "1" ]; then
		fuckAsus
	fi
	;;
stop)
  stopfuck
	dbus set fuckasd_enable=0
	;;
esac

case $2 in
web_submit)
	set_lock
	true > ${LOG_FILE}
	http_response "$1"
	if [ "${fuckasd_enable}" == "1" ]; then
		echo_date "▶️开启fuckasd！" | tee -a ${LOG_FILE}
		fuckAsus | tee -a ${LOG_FILE}
	else
		echo_date "ℹ️停止fuckasd！" | tee -a ${LOG_FILE}
		dbus set fuckasd_enable=0
		stopfuck
		echo_date "ℹ️已经停止fuckasd，建议重启重启路由！" | tee -a ${LOG_FILE}
	fi
	echo DD01N05S | tee -a ${LOG_FILE}
	unset_lock
	;;
status)
	check_status
	;;

esac

==> fuckasd_1.1.tar.gz: fuckasd/scripts/fuckasd_config.sh <==
#!/bin/sh

source /koolshare/scripts/base.sh
eval $(dbus export fuckasd_)
alias echo_date='echo 【$(TZ=UTC-8 date -R +%Y年%m月%d日\ %X)】:'
LOG_FILE=/tmp/upload/fuckasd_log.txt
FUCKASD_LOG_FILE=/tmp/upload/fuckasd.log
LOCK_FILE=/var/lock/fuckasd.lock
BASH=${0##*/}
ARGS=$@
file="asd"
target_dir="/koolshare/bin/" 
file_path=$(which "$file")

set_lock(){
	exec 999>${LOCK_FILE}
	flock -n 999 || {
		# bring back to original log
		http_response "$ACTION"
		exit 1
	}
}

unset_lock(){
	flock -u 999
	rm -rf ${LOCK_FILE}
}

number_test(){
	case $1 in
		''|*[!0-9]*)
			echo 1
			;;
		*)
			echo 0
			;;
	esac
}


checkAsus(){
	# 检查是否已fuck
	checkFuck=$(ps |grep asd |grep /bin/sh)
	if [ -n "$checkFuck" ];then
		checkfucked="1"
	else
		checkfucked="0"
	fi
}

checkASD(){
    checkAsus
    if [ "${checkfucked}" == "1" ]; then
    	echo_date "✅️恭喜！已成功FuckASD！"
    else
    	echo_date "🔴未能FuckASD，请尝试重新启动插件！"
    fi
}

fuckAsus(){
  # 检查文件是否找到
  if [ -n "$file_path" ]; then
    echo_date "✅️找到 $file，路径为 $file_path"
    
    # 构建目标挂载点
    mount_point="$target_dir/$file"

    # 检查是否已fuck
    checkAsus
    if [ "${checkfucked}" == "1" ]; then
    	echo_date "✅️已成功FuckASD,无需再次操作，退出"
    	return
    fi
    #生成挂载文件
    echo "#!/bin/sh

while true
do
sleep 86400
done" > $mount_point

    # 赋权
    chmod +x $mount_point
    
    # 执行挂载
    mount --bind "$mount_point" "$file_path"

    # 杀掉所有命令
    killall $file > /dev/null 2>&1
    killall $file > /dev/null 2>&1
    killall $file > /dev/null 2>&1

    local i=40
    local checkFuck
	  until [ -n "${checkFuck}" ]; do
	    usleep 250000
    	echo_date "ℹ️检查Fuck状态中..."
	    i=$(($i - 1))
	    checkFuck=$(ps |grep asd |grep /bin/sh)
	    if [ "$i" -lt 1 ]; then
	      echo_date "🔴Fuck失败，请稍后再次尝试。"
	      return
	    fi
  	done

    echo_date "🆗Fuck $file 成功"
  else
    echo_date "ℹ️$file 未找到，您不需要fuckasd"
    echo_date "✅️关闭插件"
    dbus set fuckasd_enable=0
  fi
}

stopfuck(){
  killall asd && unmount "$mount_point" "$file_path"
}

case $1 in
start)
	if [ "${fuckasd_enable}" == "1" ]; then
		logger "[软件中心-开机自启]: fuckasd开始自动启动！"
		fuckAsus
	else
		logger "[软件中心-开机自启]: fuckasd未开启，不自动启动！"
	fi
	;;
boot_up)
	if [ "${fuckasd_enable}" == "1" ]; then
		fuckAsus
	fi
	;;
stop)
  stopfuck
	dbus set fuckasd_enable=0
	;;
esac

case $2 in
web_submit)
	set_lock
	true > ${LOG_FILE}
	http_response "$1"
	if [ "${fuckasd_enable}" == "1" ]; then
		echo_date "▶️开启fuckasd！" | tee -a ${LOG_FILE}
		fuckAsus | tee -a ${LOG_FILE}
  elif [ "${fuckasd_enable}" == "2" ]; then
		echo_date "▶️开始检测fuckasd状态..." | tee -a ${LOG_FILE}
		dbus set fuckasd_enable=1
		checkASD | tee -a ${LOG_FILE}
	else
		echo_date "ℹ️停止fuckasd！" | tee -a ${LOG_FILE}
		dbus set fuckasd_enable=0
		stopfuck
		echo_date "ℹ️已经停止fuckasd，建议重启重启路由！" | tee -a ${LOG_FILE}
	fi
	echo DD01N05S | tee -a ${LOG_FILE}
	unset_lock
	;;
status)
	check_status
	;;

esac
